scoretools.Score
================

.. inheritance-diagram:: abjad.tools.scoretools.Score.Score.Score
   :private-bases:

.. autoclass:: abjad.tools.scoretools.Score.Score.Score

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.contents_duration

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.duration_in_seconds

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.engraver_consists

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.engraver_removals

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.is_semantic

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.leaves

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.lilypond_format

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.music

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.override

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.parent

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.preprolated_duration

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.prolated_duration

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.prolation

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.set

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.spanners

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.start_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.start_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.stop_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.stop_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.context_name

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.is_nonsemantic

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.is_parallel

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.name

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

Methods
-------

.. automethod:: abjad.tools.scoretools.Score.Score.Score.append

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.extend

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.index

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.insert

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.pop

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.remove

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

Special Methods
---------------

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__add__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__contains__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__delitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__getitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__iadd__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__imul__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__len__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__mul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__radd__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__repr__

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__rmul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__setitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`
